/*
 *  Simple test program -- simplified version of sample test hello.
 */

#include <rtems.h>
#include <stdlib.h>
#include <stdio.h>

rtems_task
Init (rtems_task_argument arg)
{
  rtems_name name_1, name_2;
  rtems_id period_1, period_2;
  rtems_status_code status;

  rtems_interval ticks_per_second;
  rtems_clock_get( RTEMS_CLOCK_GET_TICKS_PER_SECOND, &ticks_per_second );
  printf("Configured with %u ticks per second\n",ticks_per_second);

  name_1 = rtems_build_name ('P', 'E', 'R', '1');
  name_2 = rtems_build_name ('P', 'E', 'R', '2');

  status = rtems_rate_monotonic_create (name_1, &period_1);
  if (status != RTEMS_SUCCESSFUL)
    {
      printf ("rtems_monotonic_create failed with status of %d.\n", status);
      exit (1);
    }

  status = rtems_rate_monotonic_create (name_2, &period_2);
  if (status != RTEMS_SUCCESSFUL)
    {
      printf ("rtems_monotonic_create failed with status of %d.\n", status);
      exit (1);
    }

  while (1)
    {
      if (rtems_rate_monotonic_period (period_1, 1000) == RTEMS_TIMEOUT)
	break;

      if (rtems_rate_monotonic_period (period_2, 400) == RTEMS_TIMEOUT)
	break;

      /*
       *  Perform first set of actions between clock
       *  ticks 0 and 399 of every 1000 ticks.
       */
       
      printf("Action 1!\n");

      if (rtems_rate_monotonic_period (period_2, 300) == RTEMS_TIMEOUT)
	break;

      /*
       *  Perform second set of actions between clock 400 and 699
       *  of every 1000 ticks.  THEN ...
       *
       *  Check to make sure we didn't miss the period_2 period.
       */
      printf("Action 2!\n");

      usleep(3000000-1);

      if (rtems_rate_monotonic_period (period_2, status) == RTEMS_TIMEOUT)
	break;

      rtems_rate_monotonic_cancel (period_2);
    }

  /* missed period so delete period and SELF */
  printf("Missed!\n");

  rtems_rate_monotonic_delete (period_1);
  rtems_rate_monotonic_delete (period_2);
  rtems_task_delete (RTEMS_SELF);
}

/* configuration information */

#define CONFIGURE_APPLICATION_NEEDS_CONSOLE_DRIVER

#define CONFIGURE_APPLICATION_NEEDS_CLOCK_DRIVER

#define CONFIGURE_RTEMS_INIT_TASKS_TABLE

#define CONFIGURE_MAXIMUM_TASKS 1

#define CONFIGURE_MAXIMUM_PERIODS 2

#define CONFIGURE_MICROSECONDS_PER_TICK 10000

#define CONFIGURE_INIT

#include <rtems/confdefs.h>

/* end of file */
